@@ -1,8 +1,8 @@
 <?php
-// $Revision: 1.15.2.1.2.24 $
+// $Revision: 1.15.2.1.2.26 $
 // ------------------------------------------------------------------------- //
 //  XooNIps - Neuroinformatics Base Platform System                          //
-//  Copyright (C) 2005-2008 RIKEN, Japan All rights reserved.                //
+//  Copyright (C) 2005-2011 RIKEN, Japan All rights reserved.                //
 //  http://xoonips.sourceforge.jp/                                           //
 // ------------------------------------------------------------------------- //
 //  This program is free software; you can redistribute it and/or modify     //
@@ -112,7 +112,7 @@ function xnpstimulusGetListBlock( $item_basic ) {
   // set to template
   global $xoopsTpl;
 
-  $tpl = new xoopsTpl();
+  $tpl = new XoopsTpl();
   // copy variables in $xoopsTpl to $tpl
   $tpl->assign( $xoopsTpl->get_template_vars() );
 
@@ -142,7 +142,7 @@ function xnpstimulusGetDetailBlock( $item_id ) {
   }
 
   // set to template
-  $tpl = new xoopsTpl();
+  $tpl = new XoopsTpl();
   // copy variables in $xoopsTpl to $tpl
   $tpl->assign( $xoopsTpl->get_template_vars() );
 
@@ -185,7 +185,7 @@ function xnpstimulusGetPrinterFriendlyDetailBlock( $item_id ) {
   }
 
   // set to template
-  $tpl = new xoopsTpl();
+  $tpl = new XoopsTpl();
   // copy variables in $xoopsTpl to $tpl
   $tpl->assign( $xoopsTpl->get_template_vars() );
 
@@ -236,7 +236,7 @@ function xnpstimulusGetRegisterBlock() {
   // assign to template
   global $xoopsTpl;
 
-  $tpl = new xoopsTpl();
+  $tpl = new XoopsTpl();
   // variables assigned to xoopsTpl are copied to tpl
   $tpl->assign( $xoopsTpl->get_template_vars() );
 
@@ -294,7 +294,7 @@ function xnpstimulusGetEditBlock( $item_id ) {
   // assign to template
   global $xoopsTpl;
 
-  $tpl = new xoopsTpl();
+  $tpl = new XoopsTpl();
   // variables assigned to xoopsTpl are copied to tpl
   $tpl->assign( $xoopsTpl->get_template_vars() );
 
@@ -364,7 +364,7 @@ function xnpstimulusGetConfirmBlock( $item_id ) {
   // assign to template
   global $xoopsTpl;
 
-  $tpl = new xoopsTpl();
+  $tpl = new XoopsTpl();
   // variables assigned to xoopsTpl are copied to tpl
   $tpl->assign( $xoopsTpl->get_template_vars() );
 
@@ -635,7 +635,7 @@ function xnpstimulusGetAdvancedSearchBlock( &$search_var ) {
   // assign to template
   global $xoopsTpl;
 
-  $tpl = new xoopsTpl();
+  $tpl = new XoopsTpl();
   // variables assigned to xoopsTpl are copied to tpl
   $tpl->assign( $xoopsTpl->get_template_vars() );
   $tpl->assign( 'basic', $basic );
