@@ -1,8 +1,8 @@
 <?php
-// $Revision: 1.1.2.6 $
+// $Revision: 1.1.2.11 $
 // ------------------------------------------------------------------------- //
 //  XooNIps - Neuroinformatics Base Platform System                          //
-//  Copyright (C) 2005-2008 RIKEN, Japan All rights reserved.                //
+//  Copyright (C) 2005-2011 RIKEN, Japan All rights reserved.                //
 //  http://xoonips.sourceforge.jp/                                           //
 // ------------------------------------------------------------------------- //
 //  This program is free software; you can redistribute it and/or modify     //
@@ -115,6 +115,7 @@ class XooNIpsUtilityUnzip extends XooNIpsUtility {
     $this->_ecdirectory = array();
     $this->_cdirectories = array();
     $this->_entries = array();
+    return true;
   }
 
   /**
@@ -276,7 +277,8 @@ class XooNIpsUtilityUnzip extends XooNIpsUtility {
     case 0:
       // not compressed
       while ( ! feof( $this->_zfhandle ) && $size > 0 ) {
-        $buf = fread( $this->_zfhandle, $unit );
+        $len = $unit < $size ? $unit : $size;
+        $buf = fread( $this->_zfhandle, $len );
         if ( $buf === false ) {
           fclose( $ofh );
           unlink( $filepath );
@@ -287,7 +289,7 @@ class XooNIpsUtilityUnzip extends XooNIpsUtility {
           unlink( $filepath );
           return false;
         }
-        $size -= $unit;
+        $size -= $len;
       }
       break;
     case 8:
@@ -315,7 +317,8 @@ class XooNIpsUtilityUnzip extends XooNIpsUtility {
       // OS(unknown)
       fwrite( $tfh, "\xff" );
       while ( ! feof( $this->_zfhandle ) && $size > 0 ) {
-        $buf = fread( $this->_zfhandle, $unit );
+        $len = $unit < $size ? $unit : $size;
+        $buf = fread( $this->_zfhandle, $len );
         if ( $buf === false ) {
           fclose( $tfh );
           unlink( $tfn );
@@ -330,33 +333,35 @@ class XooNIpsUtilityUnzip extends XooNIpsUtility {
           unlink( $filepath );
           return false;
         }
-        $size -= $unit;
+        $size -= $len;
       }
       // CRC32
-      fwrite( $tfh, pack( 'L', $entry['crc32'] ) );
+      fwrite( $tfh, pack( 'V', $entry['crc32'] ) );
       // ISIZE
-      fwrite( $tfh, pack( 'L', $entry['uncompsize'] ) );
+      fwrite( $tfh, pack( 'V', $entry['uncompsize'] ) );
       fclose( $tfh );
       // read temporary file and write to $filepath
-      $size = $entry['compsize'];
+      $size = $entry['uncompsize'];
       $result = true;
       $tfh = gzopen( $tfn, 'rb' );
       if ( $tfh === false ) {
         unlink( $tfn );
         fclose( $ofh );
         unlink( $filepath );
+        return false;
       }
       while ( ! gzeof( $tfh ) && $size > 0 ) {
-        $buf = gzread( $tfh, $unit );
+        $len = $unit < $size ? $unit : $size;
+        $buf = gzread( $tfh, $len );
         if ( $buf == '' || false === fwrite( $ofh, $buf ) ) {
           // maybe corrupt zip file
           fclose( $tfh );
           unlink( $tfn );
           fclose( $ofh );
           unlink( $filepath );
-          break;
+          return false;
         }
-        $size -= $unit;
+        $size -= $len;
       }
       fclose( $ofh );
       fclose( $tfh );
